function I = nojman(t,i,j,L)
% NOJMAN Presmetka na podintegralniot izraz od Nojmanoviot integral.
%
%   I = nojman(t,i,j,L)
%
%   Vlez:
%       t : Vektor so vrednosti na promenlivata po koja se pravi
%           integracijata. Vrednostite se dvizat od 0 do 1 i tie vo
%           relativni edinici ja odreduvaat pozicijata na itegralnata tocka
%           po dolzinata na sprovodnikot so indeks i.
%       i : Indeks na prviot sprovodnik -- na nego presmetuvame potencijal.
%       j : Indeks na vtoriot sprovodnik -- kaj nego e injektirana struja
%           od 1 A.
%       L : Matrica so podatoci za sprovodnicite. Vo prvite 6 koloni se
%           dadeni x, y i z koordinatite na krajnite tocki od sekoj
%           sprovodnik (izrazeni vo m), a vo kolonata 7 e dijametarot na
%           sprovodnikot (izrazen vo mm).
%
%   Izlez:
%       I : Vrednost na podintegralniot izraz od Nojmanoviot integral.
%
%  See also ZAZEM.

% krajni tocki na sprovodnikot i
[A,B] = deal(L(i,1:3),L(i,4:6));

% krajni tocki na sprovodnikot j
[P,Q] = deal(L(j,1:3),L(j,4:6));
% dolzina na sprovodnikot j
dj = norm(P-Q);

% tocki po dolzina na sprovodnikot i (poziciite se dadeni vo t)
nt = length(t);
T = repmat(A',1,nt) + (B-A)'*t;

% izmestuvanje po x, y i z oska od T do P i Q
TP = T - repmat(P',1,nt);
TQ = T - repmat(Q',1,nt);

% rastojanija od T do P i Q
TP = num2cell(TP,2);
TQ = num2cell(TQ,2);
r1 = sqrt(TP{1}.^2 + TP{2}.^2 + TP{3}.^2);
r2 = sqrt(TQ{1}.^2 + TQ{2}.^2 + TQ{3}.^2);

% sredi gi mnogu bliskite tocki
r = L(j,7)/2000;
r = 0.01/2;
r12 = r1 + r2;
ind = find(abs(r12 - dj) < r);
r12(ind) = dj + r;

% presmetaj go podintegralniot izraz
I = log((r12 + dj)./(r12 - dj));
