function [X, Y, Z, fi] = potencijal_3d(datoteka,Xrange,Yrange,Zrange)
% POTENCIJAL_3D Presmetka na potencijal vo 3D okolu zazemjuvacot.
%
%   [X,Y,fi] = potencijal_3d(datoteka,Xrange,Yrange,Zrange)
%
%   Vlez:
%    datoteka : Ime na datotekata vo koja se dadeni podatocite za
%               zazemjuvacot. Detali za nejzina sodrzina moze da se vidat
%               vo zazemformat.
%    Xrange, Yrange, Zrange : Opseg na vrednosti za x, y i z koordinate vo
%               format -10:0.2:10 so koi se definira oblasta za presmetka
%               na potencijalite.
%               Ako ovie promenlivi ne se zadadat toga Xrange i Yrange se
%               odreduvaat so funkcijata def_oblast, a Zrange = -3:0.25:0;
%
%   Izlez:
%       X : Oblast na promena na koordinatite po x oska.
%       Y : Oblast na promena na koordinatite po y oska.
%       Z : Oblast na promena na koordinatite po z oska.
%      fi : Vrednost na presmetaniot potencijal.
%
%  See also ZAZEM.

[R,Rz,Uz,I,L,E,Z] = zazem(datoteka,0);
rho = Z.rho;
if nargin == 1
    [Xrange,Yrange] = def_oblast(L);
    Zrange = -3:0.25:0;
end
[X,Y,Z] = meshgrid(Xrange,Yrange,Zrange);
[nx,ny,nz] = size(X);
fi = zeros(nx,ny,nz);
for i = 1:nx
    for j = 1:ny
        for k = 1:nz
            fi(i,j,k) = potencijal_tocka([X(i,j,k) Y(i,j,k) Z(i,j,k)],[I;I],L,rho)/Uz*100;
        end
    end
end