function pot_linii = potencijal_linija(datoteka,x1,y1,x2,y2,delta)
% ZAZEM Crtanje na promenata na potencijalot dolz pravec (x1,y1)-(x2,y2)
%       na povrsinata na zemjata so cekor delta.
%
%   pot_linii = potencijal_linija(datoteka,x1,y1,x2,y2,delta)
%
%   Vlez:
%    datoteka : Ime na datotekata vo koja se dadeni podatocite za
%               zazemjuvacot. Detali za nejzina sodrzina moze da se vidat
%               vo zazemformat.
%       x1,y1 : Koordinati na pocetnata tocka
%       x2,y2 : Koordinati na krajnata tocka
%       delta : Cekor za crtanje po dolzina na linijata
%               
%    Ako se zadade samo promenlivata datoteka togas se crta promenata na
%    potencijalot po liniite zadadeni vo nea vo matricata Z.linii
%
%   Izlez:
%    pot_linii : Struktura so poveke elementi so polinja X,Y,L,fi.
%                Polinjata se vektori vo koi se dadeni koordinatite x i y
%                na tockite po dolzina na linijata, rastojanieto od
%                pocetnata tocka i vrednosta na potencijalot.
%
%  See also ZAZEM.

crtaj_zazem(datoteka);
f = gcf;
% Presmeka na potencijal dolz pravec (x1,y1)-(x2,y2) na povrsinata od zemjata
[R,Rz,Uz,I,L,E,Z] = zazem(datoteka,0);
if nargin == 1
    [x1,y1,x2,y2,delta] = ...
        deal(Z.linii(:,1),Z.linii(:,2),Z.linii(:,3),Z.linii(:,4),Z.linii(:,5));
end
nl = length(x1);
for i = 1:nl
    [x1i,y1i,x2i,y2i,deltai] = ...
        deal(x1(i),y1(i),x2(i),y2(i),delta(i));
    dx = x2i - x1i;
    dy = y2i - y1i;
    dl = sqrt(dx^2 + dy^2);
    nt = 1 + round(dl/deltai);
    xt = zeros(nt,1); yt = xt; fi = xt;
    for k = 1:nt
        xt(k) = x1i + (k - 1) * dx / (nt - 1);
        yt(k) = y1i + (k - 1) * dy / (nt - 1);
        fi(k) = 2*potencijal_tocka([xt(k) yt(k) 0],[I;I],L,Z.rho)/Uz*100;
    end
    dt = sqrt((xt - x1i).^2 + (yt - y1i).^2);
    pot_linii(i).X = xt;
    pot_linii(i).Y = yt;
    pot_linii(i).L = dt;
    pot_linii(i).fi = fi;
    naslov = sprintf('\nLinija (%.2f,%.2f) -- (%.2f,%.2f)\n',x1i,y1i,x2i,y2i);
    figure
    plot(dt,fi,'LineWidth',2)
    title(naslov)
    xlabel('L(m)'); ylabel('fi(%)');
    grid
    set(gcf,'Color',[1 1 1]);
    figure(f)
    zlabel('fi(%)');
    plot3(xt,yt,fi,'LineWidth',2)
end
